Lens Tutorial
=============

We have prepared a Lens tutorial in the form of a Jupyter notebook. A static
version is reproduced below, but you can also execute it yourself by downloading
:download:`the notebook file <./room_occupancy_example.ipynb>`.

.. notebook:: room_occupancy_example.ipynb
